@@ -1,13 +1,8 @@
-
 from PyObjCTools.TestSupport import *
 from PubSub import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
 
-class TestPSFeed (TestCase):
+class TestPSFeed(TestCase):
     def testConstants(self):
         self.assertIsInstance(PSErrorDomain, unicode)
 
@@ -29,6 +24,7 @@ class TestPSFeed (TestCase):
         self.assertResultIsBOOL(PSFeed.isRefreshing)
         self.assertResultIsBOOL(PSFeed.refresh_)
         self.assertArgIsOut(PSFeed.refresh_, 0)
+        self.assertArgIsBOOL(PSFeed.XMLRepresentationWithEntries_, 0)
 
 
 if __name__ == "__main__":
